@@ -1,11 +1,15 @@
 #![no_std]
 
 mod history;
+mod linear_map;
+mod linear_set;
 pub mod spsc;
 mod vec;
 mod vec_deque;
 
 pub use history::History;
+pub use linear_map::LinearMap;
+pub use linear_set::LinearSet;
 pub use spsc::Spsc;
 pub use vec::Vec;
 pub use vec_deque::VecDeque;
